pub struct GlobalFileChange {
pub status: DocDiffFileStatus,
pub path: String,
pub old_path: Option<String>,
pub old_text: String,
pub new_text: String,
}Expand description
One changed doc file within a single commit (the new side, plus its
old content from the first parent). The global analogue of the per-file
RevisionContent.
Fields
status: DocDiffFileStatuspath: StringRepo-relative path of the doc at this revision (the new side).
old_path: Option<String>Set when this file was renamed (the old side path).
old_text: Stringnew_text: StringTrait Implementations
Sourceimpl Clone for GlobalFileChange
impl Clone for GlobalFileChange
Sourcefn clone(&self) -> GlobalFileChange
fn clone(&self) -> GlobalFileChange
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GlobalFileChange
impl Debug for GlobalFileChange
impl Eq for GlobalFileChange
Sourceimpl PartialEq for GlobalFileChange
impl PartialEq for GlobalFileChange
impl StructuralPartialEq for GlobalFileChange