pub fn bucket_label(
point: &DocDiffTimelinePoint,
now: DateTime<Local>,
) -> StringExpand description
Bucket label for a single point relative to now: "Working tree" for
worktree points, else "Today" / "Yesterday" / "Earlier".
pub fn bucket_label(
point: &DocDiffTimelinePoint,
now: DateTime<Local>,
) -> StringBucket label for a single point relative to now: "Working tree" for
worktree points, else "Today" / "Yesterday" / "Earlier".