pub fn base_ref_for_commit_parents(_hash: &str, parents: &str) -> StringExpand description
The diff base for a commit given its space-separated parent hashes:
the first parent for normal and merge commits, or the empty tree when
there are no parents. The _hash arg is unused (parity with the original).